@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         RemoteBatchRUNJOB.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -29,6 +29,7 @@ import os
 import re
 import time
 import datetime
+import logging
 
 class RemoteBatchRUNJOB:
    def __init__(self,
@@ -53,6 +54,7 @@ class RemoteBatchRUNJOB:
                 disableProbeCheck,
                 disableStateCheck,
                 timeHistoryLogs):
+      self.logger               = logging.getLogger(__name__)
       self.hubUserName          = hubUserName
       self.hubUserId            = hubUserId
       self.runName              = runName
