@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         SitesInfo.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -30,16 +30,19 @@ import re
 import random
 import copy
 import socket
+import logging
 
-from hubzero.submit.LogMessage      import logJobId as log
+from hubzero.submit.LogMessage      import getLogJobIdMessage as getLogMessage
 from hubzero.submit.GroupMembership import isGroupMember
 
 class SitesInfo:
    def __init__(self,
                 infoDirectory,
                 sitesFile,
-                allowedVenueMechanisms):
-      self.sites = {}
+                allowedVenueMechanisms,
+                pegasusVersion):
+      self.logger = logging.getLogger(__name__)
+      self.sites  = {}
 
       sitePattern     = re.compile('(\s*\[)([^\s]*)(]\s*)')
       keyValuePattern = re.compile('( *)(\w*)( *= *)(.*[^\s$])( *)')
@@ -111,7 +114,8 @@ class SitesInfo:
                         else:
                            self.sites[siteName][key] = value
                      else:
-                        log("Undefined key = value pair %s = %s for site %s" % (key,value,siteName))
+                        message = "Undefined key = value pair %s = %s for site %s" % (key,value,siteName)
+                        self.logger.log(logging.WARNING,getLogMessage(message))
                else:
                   eof = True
             fpInfo.close()
@@ -150,6 +154,12 @@ class SitesInfo:
                   if not groupOK:
                      self.sites[site]['state'] = 'restrictedByGroup'
 
+         for site in self.sites:
+            if self.sites[site]['state'] == 'enabled':
+               if self.sites[site]['remoteBatchSystem'] == 'PEGASUS':
+                  if not pegasusVersion:
+                     self.sites[site]['state'] = 'restrictedByPegasus'
+
          for site in self.sites:
             members = self.sites[site]['members']
             if len(members) > 0:
@@ -184,10 +194,10 @@ class SitesInfo:
                   elif pegasusTemplate.endswith('.txt'):
                      self.sites[site]['pegasusTemplates']['tc']    = pegasusTemplatePath
                else:
-                  log("Pegasus template file %s does not exist." % (pegasusTemplatePath))
+                  self.logger.log(logging.ERROR,getLogMessage("Pegasus template file %s does not exist." % (pegasusTemplatePath)))
             del pegasusTemplates
       else:
-         log("Sites configuration file %s is missing" % (sitesPath))
+         self.logger.log(logging.ERROR,getLogMessage("Sites configuration file %s is missing" % (sitesPath)))
 
 
    def getEnabledSites(self):
@@ -285,11 +295,15 @@ class SitesInfo:
       for siteName in self.sites:
          site = self.sites[siteName]
          if site['state'] == 'enabled':
-            if int(nCores) < site['minimumCores']:
-               markedForDeletion.append(siteName)
-            if site['maximumCores'] > 0:
-               if int(nCores) > site['maximumCores']:
+            if   nCores > 0:
+               if nCores < site['minimumCores']:
                   markedForDeletion.append(siteName)
+               if site['maximumCores'] > 0:
+                  if nCores > site['maximumCores']:
+                     markedForDeletion.append(siteName)
+            elif nCores < 0:
+               markedForDeletion.append(siteName)
+
             if float(jobWallTime) < site['minimumWallTime']:
                markedForDeletion.append(siteName)
             if site['maximumWallTime'] > 0.:
@@ -303,11 +317,15 @@ class SitesInfo:
                   if member in self.sites:
                      memberSite = self.sites[member]
                      if memberSite['state'] == 'enabled':
-                        if int(nCores) < memberSite['minimumCores']:
-                           membersMarkedForDeletion.append(member)
-                        if memberSite['maximumCores'] > 0:
-                           if int(nCores) > memberSite['maximumCores']:
+                        if   nCores > 0:
+                           if nCores < memberSite['minimumCores']:
                               membersMarkedForDeletion.append(member)
+                           if memberSite['maximumCores'] > 0:
+                              if nCores > memberSite['maximumCores']:
+                                 membersMarkedForDeletion.append(member)
+                        elif nCores < 0:
+                           membersMarkedForDeletion.append(member)
+
                         if float(jobWallTime) < memberSite['minimumWallTime']:
                            membersMarkedForDeletion.append(member)
                         if memberSite['maximumWallTime'] > 0.:
@@ -494,27 +512,19 @@ class SitesInfo:
       selectedSites = []
 
       if len(siteNames) > 0:
-         siteNameIndex = random.randint(0,len(siteNames)-1)
-         siteName = siteNames[siteNameIndex]
-         try:
-            site    = self.sites[siteName]
-            members = site['members']
-            if len(members) > 0:
-               memberIndex = random.randint(0,len(members)-1)
-               selectedSites.append(members[memberIndex])
-            else:
+         for siteName in siteNames:
+            if not siteName in self.sites:
                selectedSites.append(siteName)
-         except:
-            markedForDeletion = []
+
+         if len(selectedSites) == 0:
             for siteName in siteNames:
-               try:
-                  site = self.sites[siteName]
-                  markedForDeletion.append(siteName)
-               except:
-                  selectedSites.append(siteName)
-            for siteName in markedForDeletion:
-               siteNames.remove(siteName)
-            del markedForDeletion
+               if siteName in self.sites:
+                  members = self.sites[siteName]['members']
+                  if len(members) > 0:
+                     for member in members:
+                        selectedSites.append(member)
+                  else:
+                     selectedSites.append(siteName)
 
       return(selectedSites)
 
@@ -642,6 +652,7 @@ class SitesInfo:
                site    = self.sites[siteName]
                members = site['members']
                if len(members) > 0:
+                  nMembersWithoutKeyValue = 0
                   for member in members:
                      if member in self.sites:
                         site = self.sites[member]
@@ -649,10 +660,14 @@ class SitesInfo:
                            if   isinstance(site[key],list):
                               if not value in site[key]:
                                  sitesWithoutKeyValue.append(member)
+                                 nMembersWithoutKeyValue += 1
                            elif site[key] != value:
                               sitesWithoutKeyValue.append(member)
+                              nMembersWithoutKeyValue += 1
                         else:
                            sitesWithoutKeyValue.append(siteName)
+                  if nMembersWithoutKeyValue == len(members):
+                     sitesWithoutKeyValue.append(siteName)
                else:
                   if key in site:
                      if   isinstance(site[key],list):
